==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/utility/units_and_measurements/measurements/_1761.py <==
"""SpecificAcousticImpedance"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_SPECIFIC_ACOUSTIC_IMPEDANCE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements",
    "SpecificAcousticImpedance",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="SpecificAcousticImpedance")
    CastSelf = TypeVar(
        "CastSelf", bound="SpecificAcousticImpedance._Cast_SpecificAcousticImpedance"
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpecificAcousticImpedance",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpecificAcousticImpedance:
    """Special nested class for casting SpecificAcousticImpedance to subclasses."""

    __parent__: "SpecificAcousticImpedance"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def specific_acoustic_impedance(self: "CastSelf") -> "SpecificAcousticImpedance":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class SpecificAcousticImpedance(_1655.MeasurementBase):
    """SpecificAcousticImpedance

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPECIFIC_ACOUSTIC_IMPEDANCE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_SpecificAcousticImpedance":
        """Cast to another type.

        Returns:
            _Cast_SpecificAcousticImpedance
        """
        return _Cast_SpecificAcousticImpedance(self)

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/utility/units_and_measurements/measurements/_1761.py <==
"""Rotatum"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_ROTATUM = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Rotatum"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Rotatum")
    CastSelf = TypeVar("CastSelf", bound="Rotatum._Cast_Rotatum")


__docformat__ = "restructuredtext en"
__all__ = ("Rotatum",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Rotatum:
    """Special nested class for casting Rotatum to subclasses."""

    __parent__: "Rotatum"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def rotatum(self: "CastSelf") -> "Rotatum":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Rotatum(_1657.MeasurementBase):
    """Rotatum

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROTATUM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Rotatum":
        """Cast to another type.

        Returns:
            _Cast_Rotatum
        """
        return _Cast_Rotatum(self)
